@@ -1,11 +1,26 @@
 import serial
 HIGH='HIGH'
 LOW='LOW'
+INPUT='INPUT'
+OUTPUT='OUTPUT'
 class ioStick:
      port="/dev/ttyS0"
      def __init__(self, serport="/dev/ttyACM0"):
           self.port=serport
-          self.ser=serial.Serial(serport,4800)
+          self.ser=serial.Serial(serport,9600)
+     def pinMode(self,pin,inout):
+          x=convert(pin)
+          y=x[0]+x[1]
+          if (inout == INPUT):
+               self.ser.write("i"+y)
+          else:
+               self.ser.write("o"+y)
+     def analogRead(self,pin):
+          x=convert(pin)
+          y=x[0]+x[1]
+          self.ser.write("a"+y)
+          output=self.ser.readline().strip()
+          return output
      def digitalWrite(self,pin,status):
           x=convert(pin)
           y=x[0]+x[1]
